You are viewing a plain text version of this content. The canonical link for it is here.
Posted to reviews@aurora.apache.org by Stephan Erb <se...@apache.org> on 2018/03/20 23:15:31 UTC

Review Request 66186: Upgrade to psutil with optimized Process.children()

-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/
-----------------------------------------------------------

Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.


Repository: aurora


Description
-------

The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`

This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
seems worthwhile. 

https://github.com/giampaolo/psutil/blob/master/HISTORY.rst


Diffs
-----

  3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
  src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 


Diff: https://reviews.apache.org/r/66186/diff/1/


Testing
-------

TODO: I still want to double check this on a real running observer


Thanks,

Stephan Erb


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Santhosh Kumar Shanmugham <sa...@gmail.com>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review201337
-----------------------------------------------------------


Ship it!




Ship It!

- Santhosh Kumar Shanmugham


On April 11, 2018, 3:13 p.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated April 11, 2018, 3:13 p.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> Successfully verified in vagrant that CPU and memory are reported as expected.
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Stephan Erb <se...@apache.org>.

> On April 12, 2018, 1:31 a.m., Reza Motamedi wrote:
> > Did you notice any real performance improvements?

No, not really :-/. But I guess that updating still does not harm.


- Stephan


-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review200944
-----------------------------------------------------------


On April 12, 2018, 12:13 a.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated April 12, 2018, 12:13 a.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> Successfully verified in vagrant that CPU and memory are reported as expected.
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Reza Motamedi <re...@gmail.com>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review200944
-----------------------------------------------------------


Ship it!




Did you notice any real performance improvements?

- Reza Motamedi


On April 11, 2018, 10:13 p.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated April 11, 2018, 10:13 p.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> Successfully verified in vagrant that CPU and memory are reported as expected.
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Renan DelValle <re...@apache.org>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review201278
-----------------------------------------------------------


Ship it!




Ship It!

- Renan DelValle


On April 11, 2018, 3:13 p.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated April 11, 2018, 3:13 p.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> Successfully verified in vagrant that CPU and memory are reported as expected.
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Stephan Erb <se...@apache.org>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/
-----------------------------------------------------------

(Updated April 12, 2018, 12:13 a.m.)


Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.


Repository: aurora


Description
-------

The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`

This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
seems worthwhile. 

https://github.com/giampaolo/psutil/blob/master/HISTORY.rst


Diffs
-----

  3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
  src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 


Diff: https://reviews.apache.org/r/66186/diff/1/


Testing (updated)
-------

Successfully verified in vagrant that CPU and memory are reported as expected.


Thanks,

Stephan Erb


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Aurora ReviewBot <wf...@apache.org>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review200267
-----------------------------------------------------------


Ship it!




Master (70d043e) is green with this patch.
  ./build-support/jenkins/build.sh

I will refresh this build result if you post a review containing "@ReviewBot retry"

- Aurora ReviewBot


On March 20, 2018, 11:15 p.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated March 20, 2018, 11:15 p.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> TODO: I still want to double check this on a real running observer
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Aurora ReviewBot <wf...@apache.org>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review199607
-----------------------------------------------------------



Master (b3fa9fe) is red with this patch.
  ./build-support/jenkins/build.sh

                     src/test/python/apache/aurora/client/hooks/test_hooked_api.py::test_api_methods_params[add_instances] <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_hooked_api.py PASSED [ 46%]
                     src/test/python/apache/aurora/client/hooks/test_hooked_api.py::test_api_methods_params[create_job] <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_hooked_api.py PASSED [ 53%]
                     src/test/python/apache/aurora/client/hooks/test_hooked_api.py::test_api_methods_params[kill_job] <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_hooked_api.py PASSED [ 60%]
                     src/test/python/apache/aurora/client/hooks/test_hooked_api.py::test_api_methods_params[restart] <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_hooked_api.py PASSED [ 66%]
                     src/test/python/apache/aurora/client/hooks/test_hooked_api.py::test_api_methods_params[start_cronjob] <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_hooked_api.py PASSED [ 73%]
                     src/test/python/apache/aurora/client/hooks/test_hooked_api.py::test_api_methods_params[start_job_update] <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_hooked_api.py PASSED [ 80%]
                     src/test/python/apache/aurora/client/hooks/test_non_hooked_api.py::TestNonHookedAuroraClientAPI::test_kill_job_discards_config <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_non_hooked_api.py PASSED [ 86%]
                     src/test/python/apache/aurora/client/hooks/test_non_hooked_api.py::TestNonHookedAuroraClientAPI::test_restart_discards_config <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_non_hooked_api.py PASSED [ 93%]
                     src/test/python/apache/aurora/client/hooks/test_non_hooked_api.py::TestNonHookedAuroraClientAPI::test_start_cronjob_discards_config <- .pants.d/pyprep/sources/86d22f98ae41c0e70ab2ce2987a3f6bb0bba61ea/apache/aurora/client/hooks/test_non_hooked_api.py PASSED [100%]
                     
                      generated xml file: /home/jenkins/jenkins-slave/workspace/AuroraBot/.pants.d/test/pytest/src.test.python.apache.aurora.client.hooks.hooks/junitxml/TEST-src.test.python.apache.aurora.client.hooks.hooks.xml 
                     =========== 15 passed in 0.32 seconds ============
                     
                   src.test.python.apache.aurora.admin.admin                                       .....   SUCCESS
                   src.test.python.apache.aurora.client.client                                     .....   SUCCESS
                   src.test.python.apache.aurora.client.api.api                                    .....   SUCCESS
                   src.test.python.apache.aurora.client.cli.cli                                    .....   SUCCESS
                   src.test.python.apache.aurora.client.docker.docker                              .....   SUCCESS
                   src.test.python.apache.aurora.client.hooks.hooks                                .....   SUCCESS
                   src.test.python.apache.aurora.common.common                                     .....   SUCCESS
                   src.test.python.apache.aurora.common.health_check.health_check                  .....   SUCCESS
                   src.test.python.apache.aurora.config.config                                     .....   SUCCESS
                   src.test.python.apache.aurora.executor.executor                                 .....   FAILURE
                   src.test.python.apache.aurora.executor.bin.bin                                  .....   SUCCESS
                   src.test.python.apache.aurora.executor.common.common                            .....   SUCCESS
                   src.test.python.apache.aurora.tools.tools                                       .....   SUCCESS
                   src.test.python.apache.thermos.cli.cli                                          .....   SUCCESS
                   src.test.python.apache.thermos.cli.commands.commands                            .....   SUCCESS
                   src.test.python.apache.thermos.common.common                                    .....   SUCCESS
                   src.test.python.apache.thermos.config.config                                    .....   SUCCESS
                   src.test.python.apache.thermos.core.core                                        .....   SUCCESS
                   src.test.python.apache.thermos.monitoring.monitoring                            .....   SUCCESS
                   src.test.python.apache.thermos.observer.observer                                .....   SUCCESS
                   src.test.python.apache.thermos.observer.http.http                               .....   SUCCESS
FAILURE


               Waiting for background workers to finish.
23:33:15 06:11   [complete]
               FAILURE


I will refresh this build result if you post a review containing "@ReviewBot retry"

- Aurora ReviewBot


On March 20, 2018, 4:15 p.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated March 20, 2018, 4:15 p.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> TODO: I still want to double check this on a real running observer
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Stephan Erb <se...@apache.org>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review199603
-----------------------------------------------------------




src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py
Line 22 (original), 22 (patched)
<https://reviews.apache.org/r/66186/#comment279928>

    `process_iter` used to be an implementation detail of `Process.children()` but got removed in https://github.com/giampaolo/psutil/pull/1185/files


- Stephan Erb


On March 21, 2018, 12:15 a.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated March 21, 2018, 12:15 a.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> TODO: I still want to double check this on a real running observer
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>


Re: Review Request 66186: Upgrade to psutil with optimized Process.children()

Posted by Stephan Erb <se...@apache.org>.
-----------------------------------------------------------
This is an automatically generated e-mail. To reply, visit:
https://reviews.apache.org/r/66186/#review200265
-----------------------------------------------------------



@ReviewBot retry

- Stephan Erb


On March 21, 2018, 12:15 a.m., Stephan Erb wrote:
> 
> -----------------------------------------------------------
> This is an automatically generated e-mail. To reply, visit:
> https://reviews.apache.org/r/66186/
> -----------------------------------------------------------
> 
> (Updated March 21, 2018, 12:15 a.m.)
> 
> 
> Review request for Aurora, Reza Motamedi and Santhosh Kumar Shanmugham.
> 
> 
> Repository: aurora
> 
> 
> Description
> -------
> 
> The changelog claims: `Process.children() is 2x faster on UNIX and 2.4x faster on Linux.`
> 
> This is needed for all stats retrieved via `ProcessTreeCollector`. An update therefore
> seems worthwhile. 
> 
> https://github.com/giampaolo/psutil/blob/master/HISTORY.rst
> 
> 
> Diffs
> -----
> 
>   3rdparty/python/requirements.txt 4ac242cfa2c1c19cb7447816ab86e748839d3d11 
>   src/test/python/apache/thermos/monitoring/test_process_collector_psutil.py 93ff878be578fa7a63d25b65e7d915790dc9ccc6 
> 
> 
> Diff: https://reviews.apache.org/r/66186/diff/1/
> 
> 
> Testing
> -------
> 
> TODO: I still want to double check this on a real running observer
> 
> 
> Thanks,
> 
> Stephan Erb
> 
>